@@ -17,9 +17,6 @@
 
 "use strict";
 
-const os = require('os');
-const fs = require('fs');
-const path = require('path');
 const child_process = require("child_process");
 
 exports.command = ['emacs [args..]'];
@@ -35,7 +32,7 @@ exports.handler = async (argv) => {
   let s_path = UTIL.el_script('core/emacs');
 
   let default_cmd = [EASK_EMACS, '-Q', '-l', s_path];
-  let rest = process.argv.slice(3);
+  let rest = UTIL.take_after(process.argv, EASK_EMACS);
   let cmd = default_cmd.concat(rest);
 
   UTIL.setup_env();
